==> joplin_2.6.2.orig.tar.gz: joplin-2.6.2/packages/server/src/views/index/help.md <==
# Joplin Cloud Help

## How can I change my details?

Most of your details can be found in your Profile page. To open it, click on the Profile button - this is the button in the top right corner, with your name or email on it.

## How can I get more space?

If you are on a Basic account, you may upgrade to a Pro account to get more space. Click on the [Profile button](#how-can-i-change-my-details), then scroll down and select "Upgrade to Pro".

If you are already on a Pro account, and you need more space for specific reasons, please contact us as we may increase the cap in some cases.

## How can I manage my payment details?

To update your card or other payment details, click on the [Profile button](#how-can-i-change-my-details), then scroll down and click on "Manage subscription".

## How can I switch to a different billing cycle or plan?

To switch between yearly and monthly payments, or to change from a Basic to Pro plan or vice versa, please click on the [Profile button](#how-can-i-change-my-details), then scroll down and click on "Manage subscription". From the Subscription page, click on Update Plan to choose your new billing cycle or to change your plan.

Note that if you downgrade from Pro to Basic, new limitations will apply so for example you may have to delete some notes so that your account is below the required limit.

## How can I cancel my account?

Click on the [Profile button](#how-can-i-change-my-details), then scroll down and click on "Manage subscription".

## Further information

- [Joplin Offical Website](https://joplinapp.org)
- [Joplin Support Forum](https://discourse.joplinapp.org/)
- [Joplin Cloud Privacy Policy](/privacy)
- [Joplin Cloud Terms & Conditions](/terms)

==> joplin_2.9.1.orig.tar.gz: joplin-2.9.1/packages/server/src/views/index/help.md <==
# Joplin Cloud Help

## How can I change my details?

Most of your details can be found in your Profile page. To open it, click on the Profile button - this is the button in the top right corner, with your name or email on it.

## How can I get more space?

If you are on a Basic account, you may upgrade to a Pro account to get more space. Click on the [Profile button](#how-can-i-change-my-details), then scroll down and select "Upgrade to Pro".

If you are already on a Pro account, and you need more space for specific reasons, please contact us as we may increase the cap in some cases.

## How can I manage my payment details?

To update your card or other payment details, click on the [Profile button](#how-can-i-change-my-details), then scroll down and click on "Manage subscription".

## How can I switch to a different billing cycle or plan?

To switch between yearly and monthly payments, or to change from a Basic to Pro plan or vice versa, please click on the [Profile button](#how-can-i-change-my-details), then scroll down and click on "Manage subscription". From the Subscription page, click on Update Plan to choose your new billing cycle or to change your plan.

Note that if you downgrade from Pro to Basic, new limitations will apply so for example you may have to delete some notes so that your account is below the required limit.

## Can my subscription be refunded?

We offer a 14 days trial when the subscription starts so that you can evaluate the service and potentially change your mind - if you cancel during that period you will not be charged. After 14 days your card will be charged and it will not be possible to issue a refund.

## How can I cancel my account?

Click on the [Profile button](#how-can-i-change-my-details), then scroll down and click on "Manage subscription". Your subscription will be cancelled and you will not be charged on what would have been the next billing period. Please note that we do not cancel accounts over email as we cannot verify your identity, however we can provide assistance if there is an issue.

## Why was I charged?

If you have been charged and you didn't expect it the most likely explanation is that the trial ended, after 14 days, and an invoice was emitted. You may have cancelled the subscription after that date, but the invoice is still due. As with everything, cancelling a contract doesn't cancel existing invoices.

## Further information

- [Joplin Offical Website](https://joplinapp.org)
- [Joplin Support Forum](https://discourse.joplinapp.org/)
- [Joplin Cloud Privacy Policy](/privacy)
- [Joplin Cloud Terms & Conditions](/terms)
